@@ -6,7 +6,7 @@ import sys
 #sys.path.append(singan_dir)
 
 
-import SinGAN
+import singan_seg_polyp.SinGAN
 
 import torch
 
